/******************************************************************************
 *
 * Copyright:
 *    (C) 2000 - 2008 Embedded Artists AB
 *
 * Description:
 *    Main program for Experiment Expansion Board (for LPC2103 Education Board)
 *
 *****************************************************************************/

#include <general.h>
#include <printf_P.h>
#include <ea_init.h>
#include <lpc2xxx.h>
#include <consol.h>
#include "adc.h"
#include "lcd.h"

/******************************************************************************
 * Defines
 *****************************************************************************/
#define INBUF_LEN 1500

#define ARP_REQUEST    1         /* Operation ARP request      */
#define ARP_REPLY      2         /* Operation ARP reply        */

#define SPI_SLAVE_CS 0x00002000  //pin P0.13
#define ENC_RESET    0x00001000  //pin P0.12
#define FAILSAFE_VALUE 5000

//#define abs(x) ((x)>0)?x:-x)

tU16 pings;

/*****************************************************************************
 *
 * Description:
 *    Delay execution by a specified number of milliseconds by using
 *    timer #1. A polled implementation.
 *
 * Params:
 *    [in] delayInMs - the number of milliseconds to delay.
 *
 ****************************************************************************/
void
delayMs(tU16 delayInMs)
{
  /*
   * setup timer #1 for delay
   */
  T1TCR = 0x02;          //stop and reset timer
  T1PR  = 0x00;          //set prescaler to zero
  T1MR0 = delayInMs * (CORE_FREQ / PBSD / 1000);
  T1IR  = 0xff;          //reset all interrrupt flags
  T1MCR = 0x04;          //stop timer on match
  T1TCR = 0x01;          //start timer
  
  //wait until delay time has elapsed
  while (T1TCR & 0x01)
    ;
}

/*****************************************************************************
 *
 * Description:
 *    The first function to execute 
 *
 ****************************************************************************/
int
main(void)
{
  tU32 i;
  tS16 Xvalue, refXvalue;
  tS16 Yvalue, refYvalue;
  tS16 Zvalue, refZvalue;
  
  eaInit();   //initialize printf

  printf("\n\n\n\n\n*******************************************************\n");
  printf("*                                                     *\n");
  printf("* Test program for 'Experiment Expansion Board'       *\n");
  printf("* running on LPC2103 Education Board.                 *\n");
  printf("* - Demo Ethernet, accelerometer and joystick         *\n");
  printf("*                                                     *\n");
  printf("* (C) Embedded Artists 2008                           *\n");
  printf("*                                                     *\n");
  printf("*******************************************************\n");

  IODIR |= 0x00006000;  //P0.13/14
  IOSET  = 0x00006000;
    
  lcdInit();
  lcdColor(0xff,0x00);
  lcdClrscr();
    
  lcdGotoxy(0,0);
  if (ethInit())
  {
    SPI_SPCR  = 0x30;  //no irq, MSB first, master, cpol=0, cpha=0
    lcdPuts("Detect: ENC28J60");
    lcdGotoxy(0,16);
    lcdPuts("Try ping at:");
    lcdGotoxy(8,32);
    lcdPuts("172.17.1.230");
  }
  else
  {
    SPI_SPCR  = 0x30;  //no irq, MSB first, master, cpol=0, cpha=0
    lcdPuts("No ENC28J60!");
  }


  lcdGotoxy(0,112);
  lcdPuts("Press any J-key");

  //While joystick is not pressed
  pings = 0;
  while ((IOPIN & 0x00001f00) == 0x00001f00)
  {
    static tU8 msgString[] = "Pings rx: xxxx";

    SPI_SPCR  = 0x20;  //no irq, MSB first, master, cpol=0, cpha=0
    ethPoll();
    SPI_SPCR  = 0x30;  //no irq, MSB first, master, cpol=0, cpha=0
    
    msgString[13] = ((pings / 1)    % 10) + '0';
    msgString[12] = ((pings / 10)   % 10) + '0';
    msgString[11] = ((pings / 100)  % 10) + '0';
    msgString[10] = ((pings / 1000) % 10) + '0';
    
    lcdGotoxy(0,70);
    lcdPuts(msgString);
  }

  //Initialize ADC
  initAdc();

  IODIR |= 0x00008000;  //P0.15

  lcdInit();
  lcdColor(0xff,0x00);
  lcdClrscr();
  lcdGotoxy(10,0);
  lcdPuts("Accelerometer");
  lcdGotoxy(35,64);
  lcdPuts("Joystick");
  
  //sensitivity of ACC
  IODIR |= (1<<13)|(1<<14);
  IOCLR = (1<<13)|(1<<14);

  delayMs(10);
  
  refXvalue = getAnalogueInput1(ACCEL_X);
  refYvalue = getAnalogueInput1(ACCEL_Y);
  refZvalue = getAnalogueInput0(ACCEL_Z);

  for(;;)
  {
    /*
         * check joystick
         */
    //check if P0.8 center-key is pressed
    if ((IOPIN & 0x00000100) == 0)
    {
      lcdGotoxy(55,80);
      lcdPuts("   ");
      lcdGotoxy(55,80+16);
      lcdPuts(" * ");
      lcdGotoxy(55,80+32);
      lcdPuts("   ");
    }
    //check if P0.9 left-key is pressed
    else if ((IOPIN & 0x00000200) == 0)
    {
      lcdGotoxy(55,80);
      lcdPuts("   ");
      lcdGotoxy(55,80+16);
      lcdPuts("<- ");
      lcdGotoxy(55,80+32);
      lcdPuts("   ");
    }
    //check if P0.10 up-key is pressed
    else if ((IOPIN & 0x00000400) == 0)
    {
      lcdGotoxy(55,80);
      lcdPuts(" A ");
      lcdGotoxy(55,80+16);
      lcdPuts(" | ");
      lcdGotoxy(55,80+32);
      lcdPuts("   ");
    }
    //check if P0.11 right-key is pressed
    else if ((IOPIN & 0x00000800) == 0)
    {
      lcdGotoxy(55,80);
      lcdPuts("   ");
      lcdGotoxy(55,80+16);
      lcdPuts(" ->");
      lcdGotoxy(55,80+32);
      lcdPuts("   ");
    }
    //check if P0.12 down-key is pressed
    else if ((IOPIN & 0x00001000) == 0)
    {
      lcdGotoxy(55,80);
      lcdPuts("   ");
      lcdGotoxy(55,80+16);
      lcdPuts(" | ");
      lcdGotoxy(55,80+32);
      lcdPuts(" V ");
    }
    else
    {
      lcdGotoxy(55,80);
      lcdPuts("   ");
      lcdGotoxy(55,80+16);
      lcdPuts("   ");
      lcdGotoxy(55,80+32);
      lcdPuts("   ");
    }

    Xvalue = getAnalogueInput1(ACCEL_X);
    Yvalue = getAnalogueInput1(ACCEL_Y);
    Zvalue = getAnalogueInput0(ACCEL_Z);
printf("\n%d|%d, %d|%d, %d|%d", Xvalue, refXvalue, Yvalue, refYvalue, Zvalue, refZvalue);


    //check if z
    if (abs(Zvalue-refZvalue) >= 75)
    {
      lcdGotoxy(55,16);
      lcdPuts("   ");
      lcdGotoxy(55,16+16);
      lcdPuts(" * ");
      lcdGotoxy(55,16+32);
      lcdPuts("   ");
      delayMs(150);
    }
    //check if P0.9 left-key is pressed
    else if (Yvalue-refYvalue >= 15)
    {
      lcdGotoxy(55,16);
      lcdPuts("   ");
      lcdGotoxy(55,16+16);
      lcdPuts("<- ");
      lcdGotoxy(55,16+32);
      lcdPuts("   ");
    }
    //check if P0.10 up-key is pressed
    else if (Xvalue-refXvalue <= -15)
    {
      lcdGotoxy(55,16);
      lcdPuts(" A ");
      lcdGotoxy(55,16+16);
      lcdPuts(" | ");
      lcdGotoxy(55,16+32);
      lcdPuts("   ");
    }
    //check if P0.11 right-key is pressed
    else if (Yvalue-refYvalue <= -15)
    {
      lcdGotoxy(55,16);
      lcdPuts("   ");
      lcdGotoxy(55,16+16);
      lcdPuts(" ->");
      lcdGotoxy(55,16+32);
      lcdPuts("   ");
    }
    //check if P0.12 down-key is pressed
    else if (Xvalue-refXvalue >= 15)
    {
      lcdGotoxy(55,16);
      lcdPuts("   ");
      lcdGotoxy(55,16+16);
      lcdPuts(" | ");
      lcdGotoxy(55,16+32);
      lcdPuts(" V ");
    }
    else
    {
      lcdGotoxy(55,16);
      lcdPuts("   ");
      lcdGotoxy(55,16+16);
      lcdPuts("   ");
      lcdGotoxy(55,16+32);
      lcdPuts("   ");
    }
  }
}

